Crate playerone_sdk_sys

Crate playerone_sdk_sys 

Structs

_POACameraProperties
_POAConfigAttributes
_POASensorModeInfo

Enums

POABayerPattern
POABool
POACameraState
POAConfig
POAErrors
POAImgFormat
POAValueType
_POABayerPattern
_POABool
_POACameraState
_POAConfig
_POAErrors
_POAImgFormat
_POAValueType

Traits

FromPOAConfigValue

Functions

POACloseCamera
@brief POACloseCamera: close the camera and free allocated memory
POAGetAPIVersion
@brief POAGetAPIVersion: get the API version
POAGetCameraCount
@brief POAGetCameraCount: get camera count
POAGetCameraProperties
@brief POAGetCameraProperties: get the property of the connected cameras, NO need to open the camera for this operation
POAGetCameraPropertiesByID
@brief POAGetCameraPropertiesByID: get the property of the connected cameras by ID, it’s a convenience function to get the property of the known camera ID
POAGetCameraState
@brief POAGetCameraState get the camera current state
POAGetConfig
@brief POAGetConfig: get the POAConfig value and auto value
POAGetConfigAttributes
@brief POAGetConfigAttributes: get POAConfig attribute by index
POAGetConfigAttributesByConfigID
@brief POAGetConfigAttributesByConfigID: get POAConfig attribute by POAConfig ID, it’s a convenience function to get the attribute of the known POAConfig ID
POAGetConfigValueType
@brief POAGetConfigValueType: get POAConfig value type
POAGetConfigsCount
@brief POAGetConfigsCount: get the count of POAConfig available for this camera
POAGetDroppedImagesCount
@brief POAGetDroppedImagesCount: get the dropped image count, reset it to 0 after stop capture
POAGetErrorString
@brief POAGetErrorString: convert POAErrors enum to char *, it is convenient to print or display errors
POAGetGainOffset
@brief POAGetGainOffset: get some preset values, Note: deprecated, please use the following function
POAGetGainsAndOffsets
@brief POAGetGainsAndOffsets: get some preset values of gain and offset @param nCameraID (input), get from in the POACameraProperties structure, use POAGetCameraProperties function @param pGainHighestDR (output), gain at highest dynamic range, in most cases, this gain is 0 @param pHCGain (output), gain at HCG Mode(High Conversion Gain) @param pUnityGain (output), unity gain(or standard gain), with this gain, eGain(e/ADU) will be 1 @param pGainLowestRN (output), aka Maximum Analog Gain, gain at lowest read noise @param pOffsetHighestDR (output), offset at highest dynamic range @param pOffsetHCGain (output), offset at HCG Mode @param pOffsetUnityGain (output), offset at unity gain @param pOffsetLowestRN (output), offset at lowest read noise @return POA_OK: operation successful POA_ERROR_INVALID_ID: no camera with this ID was found or the ID is out of boundary
POAGetImageBin
@brief POAGetImageBin: get the pixel bin method
POAGetImageData
@brief POAGetImageData: get image data after exposure, this function will block and waiting for timeout Note: recommended to use POAImageReady function for waiting, if image data ‘Is Ready’, calling this function will return immediately
POAGetImageFormat
@brief POAGetImageFormat: get image format
POAGetImageSize
@brief POAGetImageSize: get the image size of the ROI area
POAGetImageStartPos
@brief POAGetImageStartPos: get the start position of the ROI area.
POAGetSDKVersion
@brief POAGetSDKVersion: get the sdk version
POAGetSensorMode
@brief POAGetSensorMode: get camera the current sensor mode @param nCameraID (input), get from in the POACameraProperties structure, use POAGetCameraProperties function @param pModeIndex (output), pointer to a int value for saving the current sensor mode index @return POA_OK: operation successful POA_ERROR_POINTER: pModeIndex is NULL pointer POA_ERROR_INVALID_ID: no camera with this ID was found or the ID is out of boundary POA_ERROR_NOT_OPENED: camera not opened POA_ERROR_ACCESS_DENIED: camera don’t supported mode selection POA_ERROR_OPERATION_FAILED: operation failed, the current mode is not matched
POAGetSensorModeCount
@brief POAGetSensorModeCount: get the number of sensor mode
POAGetSensorModeInfo
@brief POAGetSensorModeInfo: get the camera sensor mode information according to the index
POAImageReady
@brief POAImageReady: the image data is available? if pIsReady is true, you can call POAGetImageData to get image data
POAInitCamera
@brief POAInitCamera: initialize the camera’s hardware, parameters, and malloc memory
POAOpenCamera
@brief POAOpenCamera: open the camera, note: the following API functions need to open the camera first
POASetConfig
@brief POASetConfig: set POAConfig value and auto value
POASetConfig_M
this function for matlab
POASetEnableDPS
@brief POASetEnableDPS: set the enable of the DPS(Dead Pixel Suppression) function @return POA_OK: operation successful POA_ERROR_INVALID_ID: no camera with this ID was found or the ID is out of boundary POA_ERROR_NOT_OPENED: camera not opened
POASetImageBin
@brief POASetImageBin: set the pixel bin method, note: should stop exposure first if exposing, If return successful, the image size (width & height) and start position will be changed, Please call POAGetImageStartPos and POAGetImageSize to get the new image size and start position after binning
POASetImageFormat
@brief POASetImageFormat: set image format, note: should stop exposure first if exposing
POASetImageSize
@brief POASetImageSize: set the image size of the ROI area, note: should stop exposure first if exposing
POASetImageStartPos
@brief POASetImageStartPos: set the start position of the ROI area.
POASetSensorMode
@brief POASetSensorMode: set the camera sensor mode by the index, Note: should stop exposure first if exposing
POASetUserCustomID
@brief POASetUserCustomID: set user custom ID into camera flash, if set successfully, reacquire the information of this camera to get the custom ID Note: this operation will interrupt the exposure, if start a Signal Frame exposure , the exposure progress will be terminated.
POAStartExposure
@brief POAStartExposure: start camera exposure
POAStopExposure
@brief POAStopExposure: stop camera exposure

Type Aliases

POACameraProperties
POAConfigAttributes
POAConfigValue
POASensorModeInfo

Unions

_POAConfigValue