@brief POAGetCameraPropertiesByID: get the property of the connected cameras by ID, it’s a convenience function to get the property of the known camera ID
@brief POAGetConfigAttributesByConfigID: get POAConfig attribute by POAConfig ID, it’s a convenience function to get the attribute of the known POAConfig ID
@brief POAGetGainsAndOffsets: get some preset values of gain and offset
@param nCameraID (input), get from in the POACameraProperties structure, use POAGetCameraProperties function
@param pGainHighestDR (output), gain at highest dynamic range, in most cases, this gain is 0
@param pHCGain (output), gain at HCG Mode(High Conversion Gain)
@param pUnityGain (output), unity gain(or standard gain), with this gain, eGain(e/ADU) will be 1
@param pGainLowestRN (output), aka Maximum Analog Gain, gain at lowest read noise
@param pOffsetHighestDR (output), offset at highest dynamic range
@param pOffsetHCGain (output), offset at HCG Mode
@param pOffsetUnityGain (output), offset at unity gain
@param pOffsetLowestRN (output), offset at lowest read noise
@return POA_OK: operation successful
POA_ERROR_INVALID_ID: no camera with this ID was found or the ID is out of boundary
@brief POAGetImageData: get image data after exposure, this function will block and waiting for timeout
Note: recommended to use POAImageReady function for waiting, if image data ‘Is Ready’, calling this function will return immediately
@brief POAGetSensorMode: get camera the current sensor mode
@param nCameraID (input), get from in the POACameraProperties structure, use POAGetCameraProperties function
@param pModeIndex (output), pointer to a int value for saving the current sensor mode index
@return POA_OK: operation successful
POA_ERROR_POINTER: pModeIndex is NULL pointer
POA_ERROR_INVALID_ID: no camera with this ID was found or the ID is out of boundary
POA_ERROR_NOT_OPENED: camera not opened
POA_ERROR_ACCESS_DENIED: camera don’t supported mode selection
POA_ERROR_OPERATION_FAILED: operation failed, the current mode is not matched
@brief POASetEnableDPS: set the enable of the DPS(Dead Pixel Suppression) function
@return POA_OK: operation successful
POA_ERROR_INVALID_ID: no camera with this ID was found or the ID is out of boundary
POA_ERROR_NOT_OPENED: camera not opened
@brief POASetImageBin: set the pixel bin method, note: should stop exposure first if exposing,
If return successful, the image size (width & height) and start position will be changed,
Please call POAGetImageStartPos and POAGetImageSize to get the new image size and start position after binning
@brief POASetUserCustomID: set user custom ID into camera flash, if set successfully, reacquire the information of this camera to get the custom ID
Note: this operation will interrupt the exposure, if start a Signal Frame exposure , the exposure progress will be terminated.